#
# spec file for package libmspub
#
# Copyright (c) 2019 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libmspub-0_1-1
Name:           libmspub
Version:        0.1.4
Release:        3.6
Summary:        Microsoft Publisher file format parser library
License:        MPL-2.0
Group:          Productivity/Publishing/Word
URL:            https://wiki.documentfoundation.org/DLP/Libraries/libmspub
Source:         http://dev-www.libreoffice.org/src/libmspub/libmspub-%{version}.tar.xz
Patch0:         fix-missing-include.patch
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(librevenge-0.0)
BuildRequires:  pkgconfig(librevenge-generators-0.0)
BuildRequires:  pkgconfig(librevenge-stream-0.0)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif

%description
libmspub is a library for parsing the Microsoft Publisher file format structure.

%package -n %{libname}
Summary:        Microsoft Publisher file format parser library
Group:          System/Libraries

%description -n %{libname}
libmspub is a library for parsing the Corel Draw file format structure. It is
cross-platform, at the moment it can be build on Microsoft Windows and Linux.

%package devel
Summary:        Files for Developing with libmspub
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
libmspub is a library for parsing the Microsoft Publisher file format structure.

This package contains the libmspub development files.

%package devel-doc
Summary:        Documentation for the libmspub API
Group:          Documentation/HTML
BuildArch:      noarch

%description devel-doc
This package contains documentation for the libmspub API.

%package tools
Summary:        Tools to work with publications in Microsoft Publisher file-format
Group:          Productivity/Publishing/Word

%description tools
Command line tools to work with publications in Microsoft Publisher file-format.

%prep
%autosetup -p1

%build
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
%configure \
    --disable-silent-rules \
    --disable-werror \
    --disable-static \
    --docdir=%{_docdir}/%{name}
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# docs have duped pictures
%fdupes %{buildroot}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%doc AUTHORS
%license COPYING.*
%{_libdir}/*.so.*

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/libmspub*.pc
%{_includedir}/libmspub-*

%files devel-doc
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/html

%files tools
%{_bindir}/*

%changelog
* Thu Feb 29 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Dec  3 2019 Martin Liška <mliska@suse.cz>
- Add fix-missing-include.patch in order
  to fix boo#1158322.
* Wed Mar  7 2018 tchvatal@suse.com
- Version update to 0.1.4:
  * Fix several problems found by oss-fuzz
  * Fix regression in closing shape groups that caused missing shapes
    on second and subsequent pages. (tdf#116018)
* Mon Jan  1 2018 tchvatal@suse.com
- Version update to 0.1.3:
  * Workaround a build error on some 32-bit systems.
  * Parse table row and column sizes. (tdf#89061)
  * Fix various problems when parsing broken files, found with the help of
    american-fuzzy-lop and oss-fuzz.
  * Make the output of pub2foo --help more compatible with help2man.
  * Extract more metadata from documents.
  * Require C++11 for build.
  * Drop outdated MSVC project files.
  * Handle table cells containing multiple paragraphs correctly. (tdf#89393)
  * Parse more text formatting attributes: all underline types, small
    caps, all caps, outline, emboss, engrave, shadow.
  * Parse text language.
  * Various minor changes and improvements.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Mon Aug  1 2016 tchvatal@suse.com
- Disable sle11 support code
* Tue Dec 30 2014 tchvatal@suse.com
- Version bump to 0.1.2:
  - Check arguments of public functions. Passing NULL no longer causes
    a crash.
  - Use symbol visibility on Linux. The library only exports the two public
    functions now.
  - Fix several crashes and hangs when reading broken files, found with the help
    of american-fuzzy-lop.
  - Add support for embedded fonts.
  - Add initial support for tables.
  - Parse document metadata.
- Remove libmspub-0.1.1-pkgconfig.patch
* Fri Jul 25 2014 fstrba@suse.com
- Added patch: libmspub-0.1.1-pkgconfig.patch
  * Remove the Requires.private which breaks SLE11 builds
* Tue Jul  8 2014 tchvatal@suse.com
- Version bump to 0.1.1:
  * Various small bugfixes
* Mon May 26 2014 fstrba@suse.com
- Upgrade to upstream version 0.1.0
  * ABI changes
  * Remove dependency on libwpd-devel and libwpg-devel
  * Add dependency on librevenge-devel
- License change
  * Released under MPL-2.0
* Sat Jan 25 2014 tchvatal@suse.com
- Cleanup with spec-cleaner and noarch documenation.
* Sat Jan 18 2014 crrodriguez@opensuse.org
- build with -fvisibility-inlines-hidden
* Fri Nov  1 2013 tchvatal@suse.com
- Drop conditional for doc and use verbose build.
* Mon May 27 2013 tchvatal@suse.com
- Version bump to 0.0.6:
  - various coverity and style fixes
  - deduplication using wpd code
  - few crash fixes
* Thu Feb 21 2013 tchvatal@suse.com
- Version bump to 0.0.5 - bugfix release.
* Tue Feb  5 2013 tchvatal@suse.com
- Update to 0.0.4
  * now uses icu
* Thu Nov 29 2012 tchvatal@suse.com
- Update the whitespacing and order
* Thu Nov 29 2012 tchvatal@suse.com
- Version bump to 0.0.3
  * cleanup the license string
  * disable werror explicitely
  * fdupe duped images
* Mon Aug  6 2012 fridrich.strba@suse.com
- Upgrade to upstream version 0.0.2
  * support of MS Publisher versions 98 to 2002
  * extended coverage of autoshapes for version 2003
* Mon Jun  4 2012 fridrich.strba@suse.com
- Initial package of libmspub
